
using System;
using Common.Http;
using Esim.Apis.DTO.Content;
using Microsoft.AspNetCore.Mvc;

namespace Esim.Apis.Business
{
    public interface IContentBusiness
    {
        Task<IActionResult> BannerLoad(HttpRequest httpRequest, BannerLoadReq request);

        Task<IActionResult> CustomerReviewLoad(HttpRequest httpRequest, CustomerReviewLoadReq request);
        Task<IActionResult> CustomerReviewCreate(HttpRequest httpRequest, CustomerReviewCreateReq request);

        Task<IActionResult> FaqCategoryLoad(HttpRequest httpRequest, FaqCategoryLoadReq request);
        Task<IActionResult> FaqLoad(HttpRequest httpRequest, FaqLoadReq request);

        Task<IActionResult> DeviceCompatibilityLoad(HttpRequest httpRequest, DeviceCompatibilityReq request);
        Task<IActionResult> GetDeviceBrandsAndCategories(HttpRequest httpRequest);
    }
}
